==> ultracopier-src-2.2.6.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufe die Ultimate Version um die Entwicklung zu finanzieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="440"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="674"/>
        <source>Copy list</source>
        <translation>Zu kopierende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="676"/>
        <source>Move list</source>
        <translation>Zu verschiebende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1117"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1118"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1119"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1121"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1396"/>
        <location filename="../../interface.cpp" line="1408"/>
        <location filename="../../interface.cpp" line="1420"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1495"/>
        <location filename="../../interface.cpp" line="1499"/>
        <location filename="../../interface.cpp" line="1501"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% von %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="297"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="511"/>
        <location filename="../../ThemesFactory.cpp" line="526"/>
        <location filename="../../ThemesFactory.cpp" line="541"/>
        <source>Select a color</source>
        <translation>Wählen Sie eine Farbe</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>Nach:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Dateiliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Fehlgeschlagene Dateien exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Datei(en) verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Ordner verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Datei(en) kopieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Verzeichnis kopieren</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Geschwindigkeitsbegrenzungsschieberegler anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzung</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Vorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Begrenze Übertragungsgeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Speichere Fensterposition</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit als Fortschrittsbalken anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund halten</translation>
    </message>
</context>
</TS>

==> ultracopier-src-3.0.0.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_AT">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="462"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1141"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1143"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1140"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1517"/>
        <location filename="../../interface.cpp" line="1521"/>
        <location filename="../../interface.cpp" line="1523"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% von %3</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="696"/>
        <source>Copy list</source>
        <translation>Kopier Liste</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="351"/>
        <location filename="../../interface.cpp" line="357"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufen Sie die Ultimate Version, um die Entwicklung des Programms zu unterstützen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="355"/>
        <source>Ultimate version have more performance via OS native copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="362"/>
        <source>Register your key</source>
        <translation>Produktschlüssel registrieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="698"/>
        <source>Move list</source>
        <translation>Verschieben Liste</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1139"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1418"/>
        <location filename="../../interface.cpp" line="1430"/>
        <location filename="../../interface.cpp" line="1442"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="297"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="511"/>
        <location filename="../../ThemesFactory.cpp" line="526"/>
        <location filename="../../ThemesFactory.cpp" line="541"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>Nach:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Kopiere Ordner</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Verschiebe Ordner</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Transferliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Kopiere Dateie(n)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Verschiebe Dateie(n)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportiere Fehler in Transferliste</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation>Zeige dualen Fortschritt</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Zeige Geschwindigkeit als Information</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Kopiervorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation>Generelle Toleranz</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitiere Kopiergeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit mit Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation>Genereller Abstand</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Speichere Fensterposition</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund halten</translation>
    </message>
</context>
</TS>
